Module: MusaLCEServer::Live
- Defined in:
- lib/live/live.rb,
lib/live/tracks.rb,
lib/live/handler.rb
Overview
Ableton Live integration module.
Provides support for live coding with Ableton Live 11+ through the MusaLCE for Live MIDI Remote Script.
Ableton Live integration module.
Provides support for live coding with Ableton Live 11+ through the MusaLCE for Live MIDI Remote Script.